@@ -7,7 +7,8 @@ from typing import Any, Dict
 from sphinx.application import Sphinx
 
 from .domain import BibtexDomain
-from .nodes import bibliography
+from .foot_domain import BibtexFootDomain
+from .nodes import bibliography, raw_latex, visit_raw_latex, depart_raw_latex
 from .roles import CiteRole
 from .directives import BibliographyDirective
 from .transforms import BibliographyTransform
@@ -31,15 +32,20 @@ def setup(app: Sphinx) -> Dict[str, Any]:
     app.add_config_value("bibtex_bibliography_header", "", "html")
     app.add_config_value("bibtex_footbibliography_header", "", "html")
     app.add_config_value("bibtex_reference_style", "label", "env")
+    app.add_config_value("bibtex_foot_reference_style", "foot", "env")
     app.add_domain(BibtexDomain)
     app.add_directive("bibliography", BibliographyDirective)
     app.add_role("cite", CiteRole())
     app.add_node(bibliography, override=True)
+    app.add_node(raw_latex, latex=(visit_raw_latex, depart_raw_latex),
+                 override=True)
     app.add_post_transform(BibliographyTransform)
+    app.add_domain(BibtexFootDomain)
     app.add_directive("footbibliography", FootBibliographyDirective)
     app.add_role("footcite", FootCiteRole())
 
     return {
+        'version': '2.3.0',
         'env_version': 7,
         'parallel_read_safe': True,
         'parallel_write_safe': True,
