@@ -40,6 +40,7 @@ from sphinx.util.nodes import make_refnode
 
 from .roles import CiteRole
 from .bibfile import BibFile, normpath_filename, process_bibfile
+from .nodes import raw_latex
 from .style.referencing import (
     BaseReferenceText, BaseReferenceStyle, format_references
 )
@@ -227,6 +228,7 @@ class SphinxReferenceInfo(NamedTuple):
     fromdocname: str    #: Document name of the citation reference.
     todocname: str      #: Document name of the bibliography.
     citation_id: str    #: Unique id of the citation within the bibliography.
+    title: str          #: Title attribute for reference node.
 
 
 class SphinxReferenceText(BaseReferenceText[SphinxReferenceInfo]):
@@ -239,20 +241,23 @@ class SphinxReferenceText(BaseReferenceText[SphinxReferenceInfo]):
                "SphinxReferenceText only supports the docutils backend"
         info = self.info[0]
         if info.builder.name == 'latex':
-            # latex builder needs a citation_reference
-            return [docutils.nodes.citation_reference(
-                '', *super().render(backend),
-                docname=info.todocname,
-                refname=info.citation_id)]
+            key = f'cite.{info.todocname}:{info.citation_id}'
+            return (
+                [raw_latex(f'\\hyperlink{{{key}}}{{')]
+                + super().render(backend)
+                + [raw_latex('}')]
+            )
         else:
             children = super().render(backend)
             # make_refnode only takes a single child
             refnode = make_refnode(
-                info.builder,
-                info.fromdocname,
-                info.todocname,
-                info.citation_id,
-                children[0])
+                builder=info.builder,
+                fromdocname=info.fromdocname,
+                todocname=info.todocname,
+                targetid=info.citation_id,
+                child=children[0],
+                title=info.title,
+            )
             refnode.extend(children[1:])  # type: ignore
             return [refnode]
 
@@ -262,6 +267,16 @@ def env_updated(app: "Sphinx", env: "BuildEnvironment") -> Iterable[str]:
     return domain.env_updated()
 
 
+def parse_header(header: str, source_path: str):
+    parser = docutils.parsers.rst.Parser()
+    settings = docutils.frontend.OptionParser(
+        components=(docutils.parsers.rst.Parser,)
+    ).get_default_values()
+    document = docutils.utils.new_document(source_path, settings)
+    parser.parse(header, document)
+    return document[0]
+
+
 class BibtexDomain(Domain):
     """Sphinx domain for the bibtex extension."""
 
@@ -290,10 +305,6 @@ class BibtexDomain(Domain):
     def bibliography_header(self) -> docutils.nodes.Element:
         return self.data['bibliography_header']
 
-    @property
-    def footbibliography_header(self) -> docutils.nodes.Element:
-        return self.data['footbibliography_header']
-
     @property
     def bibliographies(self) -> Dict["BibliographyKey", "BibliographyValue"]:
         """Map storing information about each bibliography directive."""
@@ -334,18 +345,11 @@ class BibtexDomain(Domain):
             process_bibfile(
                 self.bibfiles, normpath_filename(env, "/" + bibfile),
                 env.app.config.bibtex_encoding)
-        # parse bibliography headers
-        for directive in ("bibliography", "footbibliography"):
-            header = getattr(env.app.config, "bibtex_%s_header" % directive)
-            if header:
-                parser = docutils.parsers.rst.Parser()
-                settings = docutils.frontend.OptionParser(
-                    components=(docutils.parsers.rst.Parser,)
-                ).get_default_values()
-                document = docutils.utils.new_document(
-                    "%s_header" % directive, settings)
-                parser.parse(header, document)
-                self.data["%s_header" % directive] = document[0]
+        # parse bibliography header
+        header = getattr(env.app.config, "bibtex_bibliography_header")
+        if header:
+            self.data["bibliography_header"] = \
+                parse_header(header, "bibliography_header")
 
     def clear_doc(self, docname: str) -> None:
         self.data['citations'] = [
@@ -422,12 +426,14 @@ class BibtexDomain(Domain):
             if key not in citations:
                 logger.warning('could not find bibtex key "%s"' % key,
                                location=node)
+        plaintext = pybtex.plugin.find_plugin('pybtex.backends', 'plaintext')()
         references = [
             (citation.entry, citation.formatted_entry, SphinxReferenceInfo(
                 builder=builder,
                 fromdocname=fromdocname,
                 todocname=citation.bibliography_key.docname,
-                citation_id=citation.citation_id))
+                citation_id=citation.citation_id,
+                title=citation.formatted_entry.text.render(plaintext)))
             for citation in citations.values()]
         formatted_references = \
             format_references(
@@ -499,7 +505,7 @@ class BibtexDomain(Domain):
                     location=(bibliography_key.docname, bibliography.line))
                 # recover by falling back to the default
                 success = bool(cited_docnames)
-            if success:
+            if success or entry.key in bibliography.keys:
                 yield key, entry
 
     def get_sorted_entries(
